Function inspect_commit_value

pub fn inspect_commit_value<T: Config<I>, I: 'static>(
    reason: CommitReason<T, I>,
)
Queries the current value of a proprietor’s commitment.

Returns the real-time committed amount for the caller’s active commitment under the specified reason. This value reflects any changes to the underlying digest value since the commitment was placed, as digest values can be updated.

Emits

Event::CommitValue: Contains the current commitment value

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in [Pallet::inspect_commit_value].