Function inspect_slots_value

pub fn inspect_slots_value<T: Config<I>, I: 'static>(
    reason: CommitReason<T, I>,
    pool_of: PoolDigest<T>,
)
Query the values of all slots within a pool.

Returns a vector of (slot_digest, value) pairs showing how the proprietor’s total pool commitment is distributed across all pool slots.

Emits

Event::PoolSlotsValue: Contains the vector of slot-value pairs

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in [Pallet::inspect_slots_value].