pub fn inspect_index_value<T: Config<I>, I: 'static>(
reason: CommitReason<T, I>,
index_of: IndexDigest<T>,
)Expand description
Queries the total value of a proprietor’s commitment to an index.
Aggregates all entry values within the index, weighted by their respective shares, to compute the proprietor’s total exposure. Each entry’s value is computed in real-time, reflecting any changes since commitment.
Emits
Event::IndexValue: Contains the total index commitment value
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
[Pallet::inspect_index_value].