pub fn inspect_pool_commission<T: Config<I>, I: 'static>(
reason: CommitReason<T, I>,
pool_of: PoolDigest<T>,
)Expand description
Queries a pool’s commission rate.
Returns the percentage of withdrawals that the pool manager collects as commission. Commission rates are immutable after pool creation to protect depositors’ economic expectations.
Emits
Event::PoolCommission: Contains the commission rate.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
[Pallet::inspect_pool_commission].