pub fn inspect_pool_manager<T: Config<I>, I: 'static>(
reason: CommitReason<T, I>,
pool_of: PoolDigest<T>,
)Expand description
Queries a pool’s manager account.
Returns the account responsible for managing the pool’s operations, including slot configuration, share adjustments, and commission collection.
Emits
Event::PoolManager: Contains the manager’s account identifier
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
[Pallet::inspect_pool_manager].