pub fn inspect_pool_value<T: Config<I>, I: 'static>(
reason: CommitReason<T, I>,
pool_of: PoolDigest<T>,
)Expand description
Queries the total value of a proprietor’s commitment to a pool.
Aggregates all slot values within the pool, weighted by their respective shares and accounting for the pool’s commission rate.
Emits
Event::PoolValue: Contains the total pool commitment value
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
[Pallet::inspect_pool_value].