pub fn inspect_slot_value<T: Config<I>, I: 'static>(
reason: CommitReason<T, I>,
pool_of: PoolDigest<T>,
slot_of: Digest<T>,
)Expand description
Queries the value of a specific slot within a pool.
Returns the portion of the proprietor’s pool commitment allocated to this particular slot, weighted by its share within the pool.
Emits
Event::PoolSlotValue: Contains the slot’s commitment value
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
[Pallet::inspect_slot_value].